# Index of /refseq/H_sapiens/RefSeqGene

    Name                                        Last modified      Size  Parent Directory                                                 -
    presentations/                              2012-02-14 06:11    -
    Aligned2RefSeqGene                          2024-02-01 06:05  789K
    GCF_000001405.25_refseqgene_alignments.gff3 2022-10-04 14:35  2.5M
    LRG_RefSeqGene                              2024-02-01 06:07  2.5M
    README.txt                                  2016-03-29 15:33  6.8K
    gene_RefSeqGene                             2024-02-01 06:05  192K
    refseqgene.1.genomic.fna.gz                 2024-01-30 10:57   26M
    refseqgene.1.genomic.gbff.gz                2024-01-30 10:58  439M
    refseqgene.2.genomic.fna.gz                 2024-01-30 10:58   37M
    refseqgene.2.genomic.gbff.gz                2024-01-30 10:58  428M
    refseqgene.3.genomic.fna.gz                 2024-01-30 10:58   33M
    refseqgene.3.genomic.gbff.gz                2024-01-30 10:58  460M
    refseqgene.4.genomic.fna.gz                 2024-01-30 10:58   22M
    refseqgene.4.genomic.gbff.gz                2024-01-30 10:58  316M
    refseqgene.5.genomic.fna.gz                 2024-01-30 10:58   23M
    refseqgene.5.genomic.gbff.gz                2024-01-30 10:58  337M
    refseqgene.6.genomic.fna.gz                 2024-01-30 10:58   33M
    refseqgene.6.genomic.gbff.gz                2024-01-30 10:58  470M
    refseqgene.7.genomic.fna.gz                 2024-01-30 10:58   14M
    refseqgene.7.genomic.gbff.gz                2024-01-30 10:58  188M
    refseqgene.files.installed                  2024-01-30 10:58  861

HHS Vulnerability Disclosure